# Part and Assembly

```{toctree}
:caption: Objects in and Assembly
:maxdepth: 1

part
assembly
part_assembly/datum
part_assembly/engineering
part_assembly/feature
part_assembly/geometry
part_assembly/region
```
